@@ -189,7 +189,7 @@ test_that("mutate modifies same column repeatedly (#243)", {
   df <- data.frame(x = 1)
   expect_equal(mutate(df, x = x + 1, x = x + 1)$x, 3)
 
-  dt <- data.table(x = 1)
+  dt <- data.table::data.table(x = 1)
   expect_equal(mutate(dt, x = x + 1, x = x + 1)$x, 3)
 })
 
